"""Environment management package for sunologic OTEL instrumentation"""

import os
from collections import namedtuple

EnvironmentVariable = namedtuple(
    "EnvironmentVariable", ["name", "default", "description"]
)

SUMOLOGIC_OTEL_VARS = [
    EnvironmentVariable(
        "OTEL_PROPAGATORS",
        "tracecontext,baggage,b3,b3multi,jaeger,xray,ottrace",
        "Propagators to be used",
    ),
    EnvironmentVariable(
        "OTEL_TRACES_EXPORTER", "otlp_proto_http", "Traces exporter protocol"
    ),
    EnvironmentVariable(
        "OTEL_SERVICE_NAME",
        "",
        "This will appear as a tracing service name in Sumo Logic",
    ),
    EnvironmentVariable(
        "OTEL_EXPORTER_OTLP_ENDPOINT",
        "",
        "The endpoint where telemetry data will be sent. For example "
        "OTEL_EXPORTER_OTLP_ENDPOINT=http://collection-sumologic-otelcol.sumologic:55681",
    ),
    EnvironmentVariable(
        "OTEL_RESOURCE_ATTRIBUTES",
        "",
        "Resource attributes, for example the application name",
    ),
]


def generate():
    """Generates new default env conffig of OTEL"""

    for env_var in SUMOLOGIC_OTEL_VARS:
        if env_var.name not in os.environ:
            os.environ[env_var.name] = env_var.default


def dump():
    """Dumps OTEL env config"""

    # Print most important env vars first.
    for env_var in SUMOLOGIC_OTEL_VARS:
        if env_var.name in os.environ:
            print(f"# {env_var.description}")
            print(f"{env_var.name}={os.environ[env_var.name]}")

    # Print remaining OTEL env vars.
    dumped = set(env_var.name for env_var in SUMOLOGIC_OTEL_VARS)
    otel_env = (x for x in os.environ if x.startswith("OTEL_"))
    remaining_otel_env = (x for x in otel_env if x not in dumped)

    for env_var_name in remaining_otel_env:
        print(f"{env_var_name}={os.environ[env_var_name]}")



import io
import re
from os.path import abspath, dirname, join

from setuptools import find_packages, setup

here = abspath(dirname(__file__))

with open(join(here, "VERSION")) as VERSION_FILE:
    __versionstr__ = VERSION_FILE.read().strip()

with open(join(here, "requirements.txt")) as REQUIREMENTS:
    INSTALL_REQUIRES = REQUIREMENTS.read().split("\n")

with open(join(here, "requirements-extra.txt")) as REQUIREMENTS_EXTRA:
    INSTALL_REQUIRES_EXTRA = REQUIREMENTS_EXTRA.read().split("\n")

with io.open(join(here, "README.md"), encoding="utf-8") as f:
    text_type = type("")
    LONG_DESCRIPTION = re.sub(
        text_type(r":[a-z]+:`~?(.*?)`"), text_type(r"``\1``"), f.read()
    )

EXTRAS_INSTALL = {"all": INSTALL_REQUIRES_EXTRA}

setup(
    name="sumologic-opentelemetry",
    version=__versionstr__,
    description=(
        "An all-in-one package for python projects used to enable "
        "OpenTelemetry auto-instrumentation"
    ),
    long_description=LONG_DESCRIPTION,
    long_description_content_type="text/markdown",
    url="https://github.com/SumoLogic/sumologic-opentelemetry-python",
    license="Apache-2.0",
    author="Sumo Logic, Inc. Authors",
    author_email="support@sumologic.com",
    packages=find_packages(exclude=("tests",)),
    install_requires=INSTALL_REQUIRES,
    extras_require=EXTRAS_INSTALL,
    python_requires=">=3.6",
    # Trove classifiers
    # Full list: https://pypi.python.org/pypi?%3Aaction=list_classifiers
    classifiers=[
        "Development Status :: 4 - Beta",
        "License :: OSI Approved :: Apache Software License",
        "Programming Language :: Python",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
    ],
    scripts=["scripts/sumologic-opentelemetry-instrument"],
    zip_safe=True,
    include_package_data=True,
)



"""sumologic-opentelemetry - An all-in-one package

An all-in-one package for python projects used to enable OpenTelemetry auto-instrumentation"""

from . import env  # noqa

__version__ = "1.9.1"
__author__ = "Sumo Logic Authors <support@sumologic.com>"
__all__ = []
